RTLHelper class

Utility class for RTL (Right-to-Left) language support

Constructors

RTLHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

containsRTLCharacters(String text) → bool
Detects if the given text contains RTL characters
getJustifiedAlign() → TextAlign
Gets justified text alignment (works for both LTR and RTL)
getTextAlign(TextDirection direction) → TextAlign
Gets the appropriate text alignment based on text direction
getTextDirection(String text) → TextDirection
Determines the primary text direction for a given text Returns TextDirection.rtl if the text is primarily RTL, otherwise TextDirection.ltr

Constants

rtlLanguages → const Set<String>
rtlUnicodeRanges → const List<List<int>>