PagingWidget class

Inheritance

Constructors

PagingWidget({Key? key, required String htmlContent, EpubContentParser? contentParser, String bookId = '', int chapterIndex = 0, String rawFontFamily = 'Segoe', Color accentColor = Colors.indigoAccent, Color backgroundColor = Colors.white, TextStyle style = const TextStyle(color: Colors.black, fontSize: 30), required dynamic handlerCallback(PagingTextHandler handler), required VoidCallback onTextTap, required dynamic onPageFlip(int, int), required dynamic onLastPage(int, int), dynamic onFirstPageBack(int, int)?, int starterPageIndex = 0, required String chapterTitle, required int totalChapters, Widget? lastWidget})
const

Properties

accentColor → Color
final
backgroundColor → Color
final
bookId → String
final
chapterIndex → int
final
chapterTitle → String
final
contentParser → EpubContentParser?
final
handlerCallback → Function
final
hashCode → int
The hash code for this object.
no setterinherited
htmlContent → String
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastWidget → Widget?
final
onFirstPageBack → dynamic Function(int, int)?
final
onLastPage → dynamic Function(int, int)
final
onPageFlip → dynamic Function(int, int)
final
onTextTap → VoidCallback
final
rawFontFamily → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starterPageIndex → int
final
style → TextStyle
final
totalChapters → int
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _PagingWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited