BookProgressSingleton class

Constructors

BookProgressSingleton({required Isar isar})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isar → Isar
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAllBooksProgress() → Future<bool>
deleteBookProgress(String bookId) → Future<bool>
getBookProgress(String bookId) → BookProgressModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrentChapterIndex(String bookId, int chapterIndex) → Future<bool>
setCurrentPageIndex(String bookId, int pageIndex) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited