BookProgressModel class

Annotations
  • @collection
  • @Name.new("BookProgressModel")

Constructors

BookProgressModel({int? currentChapterIndex, int? currentPageIndex, String? bookId})

Properties

bookId ↔ String?
getter/setter pair
currentChapterIndex ↔ int?
getter/setter pair
currentPageIndex ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localId ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited