LocalChapterModel class

Constructors

LocalChapterModel({required String chapter, int depth = 0, String htmlContent = '', bool isSectionTitle = false})

Properties

chapter String
final
depth int
final
hashCode int
The hash code for this object.
no setterinherited
htmlContent String
final
isSectionTitle bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited