EpubContentParser class
Parses an EpubBook into a flat chapter list with infinite nesting support and extracts all images for rendering.
Uses multiple strategies to build the chapter list:
- NCX NavMap with recursive ChildNavigationPoints (handles nested TOCs)
- Falls back to epubx Chapters if NavMap is empty
- Falls back to spine order if both fail
Constructors
- EpubContentParser(EpubBook epubBook)
Properties
- epubBook → EpubBook
-
final
-
flatChapters
↔ List<
LocalChapterModel> -
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageMap
↔ Map<
String, Uint8List> -
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveImage(
String src) → Uint8List? -
resolveImagesInHtml(
String html) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited