SoftHyphenParagraph class
A text paragraph that:
- Resolves soft hyphens (\u00AD) into visible "-" at line breaks
- Renders stored highlights as colored backgrounds
- Uses Text.rich to participate in parent SelectionArea for cross-paragraph selection
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SoftHyphenParagraph
Constructors
-
SoftHyphenParagraph({Key? key, required TextSpan textSpan, TextAlign textAlign = TextAlign.justify, TextDirection textDirection = TextDirection.ltr, List<
HighlightModel> highlights = const [], String paragraphKey = '', Color? selectionColor, VoidCallback? onTap, void onHighlight(int start, int end, Color color)?}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
highlights
→ List<
HighlightModel> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onHighlight → void Function(int start, int end, Color color)?
-
final
- onTap → VoidCallback?
-
final
- paragraphKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color?
-
final
- textAlign → TextAlign
-
final
- textDirection → TextDirection
-
final
- textSpan → TextSpan
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited