HighlightModel class

Constructors

HighlightModel({required String id, required String bookId, required int chapterIndex, required String paragraphKey, required int startIndex, required int endIndex, required String selectedText, required int colorValue})
HighlightModel.fromJson(Map<String, dynamic> json)
factory

Properties

bookId String
final
chapterIndex int
final
colorValue int
final
endIndex int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
paragraphKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedText String
final
startIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateId() String
makeParagraphKey(String plainText) String
Create a stable key from paragraph text (first 50 chars + length).