HighlightStorage class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addOrUpdate(
HighlightModel highlight) → void -
getBookHighlights(
String bookId) → List< HighlightModel> -
getParagraphHighlights(
String bookId, int chapterIndex, String paragraphKey) → List< HighlightModel> -
removeAllForBook(
String bookId) → void -
removeHighlight(
String id) → void